==> ipygraphql-0.0.2.tar.gz: package/lib/BackendHandlerModel.js <==
import "core-js/modules/es.promise";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/* eslint camelcase: off */
import { WidgetModel } from '@jupyter-widgets/base';
import { version } from './version';
export class BackendHandlerModel extends WidgetModel {
  defaults() {
    return _objectSpread({}, super.defaults(), {}, {
      _model_name: 'BackendHandlerModel',
      _model_module: 'jupyter-graphql',
      _view_module_version: "^".concat(version),
      _model_module_version: "^".concat(version),
      request: null,
      response: null,
      timeout: null
    });
  }

  handleRequest(request, view) {
    if (!this.onChangeSet) {
      this.onChangeSet = true;
      this.on('change:response', () => {
        if (this.resolve) {
          this.resolve(this.get('response'));
          this.resolve = undefined;
        }
      });
    }

    if (this.resolve) {
      // eslint-disable-next-line no-console
      console.warn('Still waiting on request, ignoring new request');
      return Promise.reject(new Error('Still waiting on request, ignoring new request'));
    }

    this.set('request', request);
    this.save_changes(this.callbacks(view));
    return new Promise((resolve, reject) => {
      this.resolve = resolve;
      setTimeout(() => reject(new Error('timeout')), this.get('timeout'));
    });
  }

}
BackendHandlerModel.serializers = _objectSpread({}, WidgetModel.serializers);

==> ipygraphql-0.0.4.tar.gz: package/lib/BackendHandlerModel.js <==
import "core-js/modules/es.promise";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/* eslint camelcase: off */
import { WidgetModel } from '@jupyter-widgets/base';
import { version } from './version';
export class BackendHandlerModel extends WidgetModel {
  defaults() {
    return _objectSpread({}, super.defaults(), {}, {
      _model_name: 'BackendHandlerModel',
      _model_module: 'jupyter-graphql',
      _view_module_version: "^".concat(version),
      _model_module_version: "^".concat(version),
      request: null,
      response: null,
      timeout: null
    });
  }

  handleRequest(request, view) {
    if (!this.onChangeSet) {
      this.onChangeSet = true;
      this.on('change:response', () => {
        if (this.resolve && this.get('response')) {
          this.resolve(this.get('response'));
          this.resolve = undefined;
        }
      });
    }

    if (this.resolve) {
      // eslint-disable-next-line no-console
      console.warn('Still waiting on request, ignoring new request');
      return Promise.reject(new Error('Still waiting on request, ignoring new request'));
    }

    this.set('request', request);
    this.save_changes(this.callbacks(view));
    return new Promise((resolve, reject) => {
      this.resolve = resolve;
      setTimeout(() => {
        this.resolve = undefined;
        reject(new Error('timeout'));
      }, this.get('timeout'));
    });
  }

}
BackendHandlerModel.serializers = _objectSpread({}, WidgetModel.serializers);
